@@ -1,7 +1,7 @@
 package  # hide from PAUSE
    P9Y::ProcessTable;
 
-our $VERSION = '0.95_002'; # VERSION
+our $VERSION = '0.95_003'; # VERSION
 
 #############################################################################
 # Modules
@@ -77,7 +77,8 @@ sub _process_hash {
    # process simple cats
    foreach my $fn (qw{cmdline}) {
       my $file = $pdir->file($fn);
-      $hash->{$fn} = $file->slurp if (-f $file);
+      next unless (-f $file);
+      $hash->{$fn} = $file->slurp;
       $hash->{$fn} =~ s/\0/ /g;
       $hash->{$fn} =~ s/^\s+|\s+$//g;
    }
